Class: Shoryuken::Runner
- Inherits:
-
Object
- Object
- Shoryuken::Runner
- Includes:
- Util, Singleton
- Defined in:
- lib/shoryuken/runner.rb
Overview
Runs the Shoryuken server process. Handles signal trapping, daemonization, and lifecycle management.
Instance Attribute Summary collapse
-
#launcher ⇒ Shoryuken::Launcher?
readonly
The launcher instance, or nil if not yet initialized.
Instance Method Summary collapse
-
#healthy? ⇒ Boolean
Checks if the server is healthy.
-
#run(options) ⇒ void
Runs the Shoryuken server with the given options.
Methods included from Util
#elapsed, #fire_event, #logger, #unparse_queues, #worker_name
Instance Attribute Details
#launcher ⇒ Shoryuken::Launcher? (readonly)
Returns the launcher instance, or nil if not yet initialized.
19 20 21 |
# File 'lib/shoryuken/runner.rb', line 19 def launcher @launcher end |
Instance Method Details
#healthy? ⇒ Boolean
Checks if the server is healthy
67 68 69 |
# File 'lib/shoryuken/runner.rb', line 67 def healthy? (@launcher && @launcher.healthy?) || false end |
#run(options) ⇒ void
This method returns an undefined value.
Runs the Shoryuken server with the given options
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/shoryuken/runner.rb', line 29 def run() self_read, self_write = IO.pipe %w[INT TERM USR1 TSTP TTIN].each do |sig| trap sig do self_write.puts(sig) end rescue ArgumentError puts "Signal #{sig} not supported" end loader = EnvironmentLoader.() daemonize(Shoryuken.) write_pid(Shoryuken.) loader.load initialize_concurrent_logger @launcher = Shoryuken::Launcher.new begin @launcher.start while (readable_io = IO.select([self_read])) signal = readable_io.first[0].gets.strip handle_signal(signal) end rescue Interrupt @launcher.stop! exit 0 end end |