Module: Shoryuken
- Extended by:
- SingleForwardable
- Defined in:
- lib/shoryuken.rb,
lib/shoryuken/util.rb,
lib/shoryuken/queue.rb,
lib/shoryuken/client.rb,
lib/shoryuken/errors.rb,
lib/shoryuken/runner.rb,
lib/shoryuken/worker.rb,
lib/shoryuken/fetcher.rb,
lib/shoryuken/logging.rb,
lib/shoryuken/manager.rb,
lib/shoryuken/message.rb,
lib/shoryuken/options.rb,
lib/shoryuken/version.rb,
lib/shoryuken/launcher.rb,
lib/shoryuken/processor.rb,
lib/active_job/extensions.rb,
lib/shoryuken/body_parser.rb,
lib/shoryuken/logging/base.rb,
lib/shoryuken/inline_message.rb,
lib/shoryuken/logging/pretty.rb,
lib/shoryuken/worker_registry.rb,
lib/shoryuken/middleware/chain.rb,
lib/shoryuken/middleware/entry.rb,
lib/shoryuken/environment_loader.rb,
lib/shoryuken/helpers/hash_utils.rb,
lib/shoryuken/helpers/timer_task.rb,
lib/shoryuken/helpers/atomic_hash.rb,
lib/shoryuken/helpers/string_utils.rb,
lib/shoryuken/polling/base_strategy.rb,
lib/shoryuken/active_job/job_wrapper.rb,
lib/shoryuken/helpers/atomic_boolean.rb,
lib/shoryuken/helpers/atomic_counter.rb,
lib/shoryuken/worker/inline_executor.rb,
lib/shoryuken/default_worker_registry.rb,
lib/shoryuken/polling/strict_priority.rb,
lib/shoryuken/worker/default_executor.rb,
lib/shoryuken/middleware/server/timing.rb,
lib/shoryuken/default_exception_handler.rb,
lib/shoryuken/logging/without_timestamp.rb,
lib/shoryuken/polling/queue_configuration.rb,
lib/shoryuken/polling/weighted_round_robin.rb,
lib/shoryuken/active_job/current_attributes.rb,
lib/shoryuken/middleware/server/auto_delete.rb,
lib/shoryuken/middleware/server/active_record.rb,
lib/shoryuken/middleware/server/auto_extend_visibility.rb,
lib/shoryuken/middleware/server/non_retryable_exception.rb,
lib/shoryuken/middleware/server/exponential_backoff_retry.rb
Overview
Shoryuken is a super efficient AWS SQS thread based message processor. It provides a simple interface to process SQS messages using Ruby workers.
Defined Under Namespace
Modules: ActiveJob, Errors, Helpers, Logging, Middleware, Polling, Util, Worker Classes: BodyParser, Client, DefaultExceptionHandler, DefaultWorkerRegistry, EnvironmentLoader, Fetcher, InlineMessage, Launcher, Manager, Message, Options, Processor, Queue, Runner, WorkerRegistry
Constant Summary collapse
- VERSION =
Current version of the Shoryuken gem
'7.0.2'
Class Method Summary collapse
-
.healthy? ⇒ Boolean
Checks if the Shoryuken server is running and healthy.
-
.shoryuken_options ⇒ Shoryuken::Options
Returns the global Shoryuken configuration options instance.
Class Method Details
.healthy? ⇒ Boolean
Checks if the Shoryuken server is running and healthy. A server is considered healthy when all configured processing groups are running and able to process messages.
35 36 37 |
# File 'lib/shoryuken.rb', line 35 def self.healthy? Shoryuken::Runner.instance.healthy? end |
.shoryuken_options ⇒ Shoryuken::Options
Returns the global Shoryuken configuration options instance. This is used internally for storing and accessing configuration settings.
26 27 28 |
# File 'lib/shoryuken.rb', line 26 def self. @_shoryuken_options ||= Shoryuken::Options.new end |